==> web-react-0.0.20.tgz: package/HTML.esm.js <==
import './index.esm2.js';
import { useRef, useEffect } from 'react';
import ReactHtmlParser from 'html-react-parser';
import PropTypes from 'prop-types';
import { jsx } from 'react/jsx-runtime';
import '@qubejs/core';
import '@reduxjs/toolkit';
import '@mui/material/Button';
import '@mui/material/IconButton';
import '@mui/material/Typography';
import '@mui/material/Dialog';
import '@mui/material/DialogTitle';
import '@mui/material/DialogActions';
import '@mui/material/DialogContent';
import '@mui/material/Slide';
import '@mui/material/LinearProgress';
import '@mui/material/CircularProgress';
import '@mui/icons-material/SelectAll';
import '@mui/lab/Alert';
import '@mui/lab/AlertTitle';
import '@mui/material/Autocomplete';
import '@mui/material/Chip';
import '@mui/material/Box';
import '@mui/material';
import '@mui/material/TextField';
import '@mui/material/BottomNavigation';
import '@mui/material/BottomNavigationAction';
import '@mui/material/Breadcrumbs';
import '@mui/icons-material/NavigateNext';
import '@mui/material/ButtonGroup';
import '@mui/material/Tooltip';
import '@mui/material/FormLabel';
import '@mui/material/FormControl';
import '@mui/material/FormControlLabel';
import '@mui/material/Checkbox';
import '@mui/material/FormGroup';
import '@mui/material/FormHelperText';
import '@mui/material/Menu';
import '@mui/material/MenuItem';
import '@mui/material/ListItemIcon';
import '@mui/material/Divider';
import '@mui/material/List';
import '@mui/material/ListItem';
import '@mui/material/ListItemButton';
import '@mui/material/ListItemText';
import '@mui/material/Collapse';
import '@mui/material/Avatar';
import '@mui/material/Select';
import '@mui/material/OutlinedInput';
import '@mui/material/Input';
import '@mui/material/InputLabel';
import '@mui/material/Pagination';
import '@mui/material/Radio';
import '@mui/material/RadioGroup';
import 'react-google-recaptcha';
import '@mui/material/Skeleton';
import '@mui/material/Snackbar';
import '@mui/icons-material/Close';
import '@mui/material/Switch';
import '@mui/material/Tabs';
import '@mui/material/Tab';
import 'react-dom';
import 'react-router-dom';
import '@mui/lab/TreeView';
import '@mui/icons-material/ExpandMore';
import '@mui/icons-material/ChevronRight';
import '@mui/lab/TreeItem';

const HTML = ({
  className: _className = '',
  value: _value = '',
  html: _html = '',
  onAction
}) => {
  const container = useRef();
  const handleClick = e => {
    var _targetToCheck$getAtt;
    let targetToCheck = e.target;
    while (targetToCheck.getAttribute('data-html-root') !== 'root' && targetToCheck && !targetToCheck.getAttribute('href')) {
      targetToCheck = targetToCheck.parentElement;
    }
    if (targetToCheck && (targetToCheck.getAttribute('data-action-type') || ((_targetToCheck$getAtt = targetToCheck.getAttribute('href')) == null ? void 0 : _targetToCheck$getAtt.indexOf('download-doc')) > -1)) {
      var _targetToCheck$getAtt2;
      e.stopPropagation();
      e.preventDefault();
      let actionType = targetToCheck.getAttribute('data-action-type');
      if (((_targetToCheck$getAtt2 = targetToCheck.getAttribute('href')) == null ? void 0 : _targetToCheck$getAtt2.indexOf('download-doc')) > -1) {
        actionType = 'download-doc';
      }
      let params = {};
      for (var i = 0; i < targetToCheck.attributes.length; i++) {
        params[targetToCheck.attributes[i].name] = targetToCheck.attributes[i].value;
      }
      onAction && onAction({}, Object.assign({
        actionType
      }, params));
    }
  };
  useEffect(() => {
    container.current.addEventListener('click', handleClick, false);
  }, []);
  return /*#__PURE__*/jsx("div", {
    className: `sq-html ${_className}`,
    "data-html-root": "root",
    children: /*#__PURE__*/jsx("div", {
      className: "sq-html__container",
      ref: container,
      children: /*#__PURE__*/jsx("div", {
        className: "sq-html__html",
        children: ReactHtmlParser(_html || _value)
      })
    })
  });
};
HTML.propTypes = {
  className: PropTypes.string,
  value: PropTypes.any
};

export { HTML as default };

==> web-react-0.0.25.tgz: package/HTML.esm.js <==
import { h as htmlReactParser } from './index.esm2.js';
import { useRef, useEffect } from 'react';
import PropTypes from 'prop-types';
import { jsx } from 'react/jsx-runtime';
import '@qubejs/core';
import '@mui/material/Button';
import '@mui/material/IconButton';
import '@mui/material/Typography';
import '@mui/material/Dialog';
import '@mui/material/DialogTitle';
import '@mui/material/DialogActions';
import '@mui/material/DialogContent';
import '@mui/material/Slide';
import '@mui/material/LinearProgress';
import '@mui/material/CircularProgress';
import '@mui/icons-material/SelectAll';
import '@mui/lab/Alert';
import '@mui/lab/AlertTitle';
import '@mui/material/Autocomplete';
import '@mui/material/Chip';
import '@mui/material/Box';
import '@mui/material';
import '@mui/material/TextField';
import '@mui/material/BottomNavigation';
import '@mui/material/BottomNavigationAction';
import '@mui/material/Breadcrumbs';
import '@mui/icons-material/NavigateNext';
import '@mui/material/ButtonGroup';
import '@mui/material/Tooltip';
import '@mui/material/FormLabel';
import '@mui/material/FormControl';
import '@mui/material/FormControlLabel';
import '@mui/material/Checkbox';
import '@mui/material/FormGroup';
import '@mui/material/FormHelperText';
import '@mui/material/Menu';
import '@mui/material/MenuItem';
import '@mui/material/ListItemIcon';
import '@mui/material/Divider';
import '@mui/material/List';
import '@mui/material/ListItem';
import '@mui/material/ListItemButton';
import '@mui/material/ListItemText';
import '@mui/material/Collapse';
import '@mui/material/Avatar';
import '@mui/material/Select';
import '@mui/material/OutlinedInput';
import '@mui/material/Input';
import '@mui/material/InputLabel';
import '@mui/material/Pagination';
import '@mui/material/Radio';
import '@mui/material/RadioGroup';
import 'react-google-recaptcha';
import '@mui/material/Skeleton';
import '@mui/material/Snackbar';
import '@mui/icons-material/Close';
import '@mui/material/Switch';
import '@mui/material/Tabs';
import '@mui/material/Tab';
import 'react-dom';
import 'react-router-dom';
import '@mui/lab/TreeView';
import '@mui/icons-material/ExpandMore';
import '@mui/icons-material/ChevronRight';
import '@mui/lab/TreeItem';

const HTML = ({
  className: _className = '',
  value: _value = '',
  html: _html = '',
  onAction
}) => {
  const container = useRef();
  const handleClick = e => {
    var _targetToCheck$getAtt;
    let targetToCheck = e.target;
    while (targetToCheck.getAttribute('data-html-root') !== 'root' && targetToCheck && !targetToCheck.getAttribute('href')) {
      targetToCheck = targetToCheck.parentElement;
    }
    if (targetToCheck && (targetToCheck.getAttribute('data-action-type') || ((_targetToCheck$getAtt = targetToCheck.getAttribute('href')) == null ? void 0 : _targetToCheck$getAtt.indexOf('download-doc')) > -1)) {
      var _targetToCheck$getAtt2;
      e.stopPropagation();
      e.preventDefault();
      let actionType = targetToCheck.getAttribute('data-action-type');
      if (((_targetToCheck$getAtt2 = targetToCheck.getAttribute('href')) == null ? void 0 : _targetToCheck$getAtt2.indexOf('download-doc')) > -1) {
        actionType = 'download-doc';
      }
      let params = {};
      for (var i = 0; i < targetToCheck.attributes.length; i++) {
        params[targetToCheck.attributes[i].name] = targetToCheck.attributes[i].value;
      }
      onAction && onAction({}, Object.assign({
        actionType
      }, params));
    }
  };
  useEffect(() => {
    container.current.addEventListener('click', handleClick, false);
  }, []);
  return /*#__PURE__*/jsx("div", {
    className: `sq-html ${_className}`,
    "data-html-root": "root",
    children: /*#__PURE__*/jsx("div", {
      className: "sq-html__container",
      ref: container,
      children: /*#__PURE__*/jsx("div", {
        className: "sq-html__html",
        children: htmlReactParser(_html || _value)
      })
    })
  });
};
HTML.propTypes = {
  className: PropTypes.string,
  value: PropTypes.any
};

export { HTML as default };
